import axios from "axios";

function getCurrentTimestamp() {
    return new Date().getTime();
}

const api = 'http://nbxt.oa.x-lf.cn'

/**
 * 根据项目id获取项目信息
 * @param id 项目id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
const projectGetById = (id, token) => {
    return axios({
        url: api + "/project/get/id?id=" + id,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        }
    })
}


/**
 * 获取项目信息
 * @param projectId 项目id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */

export const getproject = (projectId, token) => {
    return axios({
        url: api +"/project/get?projectId=" + projectId,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()

        }


    })
}



/**
 * 获取我管理页面的项目列表(接口有问题)
 * 
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
export const getManageList = (token) => {
    return axios({
        url: api +"/project/child/get" ,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
           
            'Timestamp': getCurrentTimestamp()
            

        }


    })
}

// 我管理的所有接口


/**
 * 获取我管理的页面的搜索
 * 
 * @param projectId 项目id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
export const getManageListById = (projectId, token) => {
    return axios({
        url: api +'/project/get/' + projectId,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        }

    })

}
/**
 * 获取我管理的页面的项目列表
 * 
 * @param projectId 项目id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
export const getManageProjectList = (token) => {
    return axios({
        url: api +'/project/child/get' ,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        }

    })

}






/**
 * 获取我管理的页面的子模块项目列表
 * 
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
export const getProjectList = (token) => {
    return axios({
        url: api +"/project/module/get" ,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        }


    })
}
/**
 * 获取我管理的页面的子系统项目列表
 * @param projectId 项目id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
export const getProjectSysList = (projectId,token) => {
    return axios({
        url: api +"/module/get?projectId=" + projectId ,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        }


    })
}
/**
 * 获取我管理的页面的子模块项目列表(接口没数据)
 * @param sysId 子系统id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
export const getProjectModList = (sysId,token) => {
    return axios({
        url: api +"/module/get/min?sysId=" + sysId ,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        }


    })
}
/**
 * 获取我管理的页面的子模块详细信息
 * @param id 子模块id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
export const getProjectModDetail = (id,token) => {
    return axios({
        url: api +"/project/module/id?id=" + id ,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        }


    })
}






